@@ -11,6 +11,7 @@ BOTTOM_TOOLBAR_TXT : str
     The text for the help bar of the CLI.
 """
 import os
+import re
 import sys
 from pathlib import Path
 from typing import Dict, List, Tuple
@@ -340,7 +341,8 @@ class CLI:
             rich.print(columns)
             return
 
-        self.command += user_input + " "
+        self.command += user_input + "|"
+        # print(f'Self.command is now {self.command}')
         if self.sql_mode:
             if not user_input:
 
@@ -358,7 +360,10 @@ class CLI:
             if not user_input:
                 self.has_one_blank = False
                 if self.command and self.command.strip().rstrip("") != "":
-                    sql = prql.to_sql(self.command)
+
+                    cleaned = self.clean_input(self.command)
+                    print(f"PRQL:\t{self.highlight_prql(cleaned)}")
+                    sql = prql.to_sql(cleaned)
                     to = ""
                     if "TO" in sql:
                         to = sql[sql.index("TO") :].strip()
@@ -418,3 +423,6 @@ class CLI:
                 self.command = ""
                 self.prompt_text = "PRQL> "
                 self.has_one_blank = False
+
+    def clean_input(self, command: str) -> str:
+        return re.sub(r"\|+", r"|", command.rstrip("|"))
